@@ -2,13 +2,11 @@ use strict;
 use warnings;
 
 package SubSubClass;
-our $VERSION = '0.16_01';
+our $VERSION = '0.05';
 
 
 use base qw/OtherSubClass/;
 
-sub meta { 'foo' } # Test having a meta method..
-
 sub bar : Quux {}
 
 1;
